emacs-diffs
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[Emacs-diffs] Changes to emacs/src/w32font.c,v


From: Jason Rumney
Subject: [Emacs-diffs] Changes to emacs/src/w32font.c,v
Date: Tue, 11 Mar 2008 00:36:21 +0000

CVSROOT:        /sources/emacs
Module name:    emacs
Changes by:     Jason Rumney <jasonr>   08/03/11 00:36:21

Index: w32font.c
===================================================================
RCS file: /sources/emacs/emacs/src/w32font.c,v
retrieving revision 1.17
retrieving revision 1.18
diff -u -b -r1.17 -r1.18
--- w32font.c   7 Mar 2008 00:44:49 -0000       1.17
+++ w32font.c   11 Mar 2008 00:36:21 -0000      1.18
@@ -783,8 +783,9 @@
 
   GetTextMetrics (dc, &w32_font->metrics);
 
-  /* Cache ASCII metrics.  */
   w32_font->glyph_idx = ETO_GLYPH_INDEX;
+
+  /* Cache ASCII metrics.  */
   recompute_cached_metrics (dc, w32_font);
 
   SelectObject (dc, old_font);
@@ -1717,8 +1718,9 @@
       if (outline)
         {
           float pointsize = height * 72.0 / one_w32_display_info.resy;
-          /* Round to nearest half point.  */
-          pointsize = round (pointsize * 2) / 2;
+          /* Round to nearest half point.  floor is used, since round is not
+            supported in MS library.  */
+          pointsize = floor (pointsize * 2 + 0.5) / 2;
           p += sprintf (p, "-%1.1f", pointsize);
         }
       else




reply via email to

[Prev in Thread] Current Thread [Next in Thread]